pub struct RouteHandle {
pub channel: u16,
pub epoch: u32,
/* private fields */
}Expand description
Immutable identity of one route binding on one live connection.
Only channel and epoch are serialized. The private connection token prevents
work retained from an earlier connection from acting on a later connection that
happens to reuse the same wire pair.
Fields
channel: u16epoch: u32Trait Implementations
Sourceimpl Clone for RouteHandle
impl Clone for RouteHandle
Sourcefn clone(&self) -> RouteHandle
fn clone(&self) -> RouteHandle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for RouteHandle
Sourceimpl Debug for RouteHandle
impl Debug for RouteHandle
impl Eq for RouteHandle
Sourceimpl Hash for RouteHandle
impl Hash for RouteHandle
Sourceimpl PartialEq for RouteHandle
impl PartialEq for RouteHandle
impl StructuralPartialEq for RouteHandle